@@ -4,6 +4,19 @@
 # require
 from rdr import *
 
+
+# make sure the NLTK is sane
+def checkForPunkt() :
+
+	# require
+	import nltk
+		
+	try : nltk.data.find( 'tokenizers/punkt' )
+	except LookupError : 
+		click.echo( "Installing punkt. This ought to only happen once.", err=True )
+		nltk.download( 'punkt', quiet=True )
+
+
 @click.command( options_metavar='[<options>]' )
 @click.option('-w', '--width', default=80, help='number of characters in each line of output')
 @click.option('-l', '--lines', default=999, help='number of lines of text to output')
@@ -26,14 +39,15 @@ def concordance( carrel, query, width, lines ) :
 	# require
 	from nltk import Text, word_tokenize
 
-	# sanity check
+	# sanity checks
 	checkForCarrel( carrel )
-
-	# initialize, read, and normalize; ought to save the Text object for future use
+	checkForPunkt()
+	
+	# initialize, read, and normalize; ought to save the result for future use
 	localLibrary = configuration( 'localLibrary' )
 	corpus       = localLibrary/carrel/ETC/CORPUS
 	text         = Text( word_tokenize( open( corpus ).read( ) ) )
-	
+					
 	# split query into a list, conditionally
 	if ' ' in query : query = query.split( ' ' )
 		
